ElectronicBandStructure — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# ElectronicBandStructure

The `pyprocar.core.ElectronicBandStructure` class is used to store and manipulate electronic band structure information. Electronic band structures expects kpoints, band values, fermi energy, projections, phase projections, kpath, weights, and reciprocal lattice.

See ElectronicBandStructure for further details.

`pyprocar.core.ElectronicBandStructure`(...[, ...]) | This object stores electronic band structure informomration.